MolFlux
=======

**MolFlux** is a foundational package for molecular predictive modelling. From data to features to models, MolFlux
provides you with a complete ecosystem for building and handling machine learning models!

````{grid} 2
```{grid-item-card} 💡[Tutorials](pages/tutorials/esol_reg.md)
Learn the basics of MolFlux by jumping straight into examples!
```
```{grid-item-card} 📏 [Standard API](pages/standard_api/intro.md)
The Standard API of MolFlux allows you to easily use the different modules. Learn more here!
```
````

To learn more about the individual components of MolFlux, check out the documentation for each module below!

````{grid} 3
```{grid-item-card} 🗂 [Datasets](pages/datasets/intro.md)
Get started with loading, handling, and manipulating datasets.
```
```{grid-item-card} 🌈 [Features](pages/features/intro.md)
Features are an important part of building machine learning models. Learn how to use them here!
```
```{grid-item-card} 🔀 [Splits](pages/splits/intro.md)
There are many ways to split your data for model benchmarking.
```
````

````{grid} 2
```{grid-item-card} 🤖 [ModelZoo](pages/modelzoo/intro.md)
Jump into the many model architectures accessible through MolFlux!
```
```{grid-item-card} 📈 [Metrics](pages/metrics/intro.md)
Measure your model performance using a variety of metrics!
```
````

```{toctree}
---
hidden:
glob:
maxdepth: 2
caption: Philosophy
---
pages/philosophy
```

```{toctree}
---
hidden:
glob:
maxdepth: 2
caption: Standard API
---
pages/standard_api/intro
```

```{toctree}
---
hidden:
glob:
maxdepth: 2
caption: Tutorials
---
pages/tutorials/esol_reg
pages/tutorials/esol_cls
pages/tutorials/esol_uncertainty
pages/tutorials/qm9_reg_3d
```

```{toctree}
---
hidden:
glob:
maxdepth: 2
caption: Datasets
---
pages/datasets/intro
pages/datasets/basic_usage
pages/datasets/loading
pages/datasets/saving
pages/datasets/featurising
pages/datasets/splitting
```

```{toctree}
---
hidden:
glob:
maxdepth: 2
caption: Features
---
pages/features/intro
pages/features/basic_usage
pages/features/how_to_add_reps
```

```{toctree}
---
hidden:
glob:
maxdepth: 2
caption: Splits
---
pages/splits/intro
pages/splits/basic_usage
pages/splits/how_to_add_splits
pages/splits/gallery
```

```{toctree}
---
hidden:
glob:
maxdepth: 2
caption: ModelZoo
---
pages/modelzoo/intro
pages/modelzoo/basic_usage
pages/modelzoo/uncertainty
pages/modelzoo/how_to_add_models
```

```{toctree}
---
hidden:
glob:
maxdepth: 2
caption: Metrics
---
pages/metrics/intro
pages/metrics/basic_usage
pages/metrics/how_to_add_metrics
```

```{toctree}
---
hidden:
glob:
maxdepth: 2
caption: Productionising
---
pages/production/intro
pages/production/featurisation
pages/production/models
pages/production/tracking
```

```{toctree}
---
hidden:
maxdepth: 2
caption: Reference
---
pages/reference/catalogue/index
API <pages/reference/api/modules.rst>
```
